//+------------------------------------------------------------------+
//|                                                     Emission.mqh |
//|                                           Copyright 2013, DC2008 |
//|                           https://login.mql5.com/ru/users/DC2008 |
//+------------------------------------------------------------------+
#property copyright "Copyright 2013, DC2008"
#property link      "https://login.mql5.com/ru/users/DC2008"
#property version   "1.00"
#define  BIG   7    //  
#define  SMALL 3    //  
//+------------------------------------------------------------------+
//|  pMABB                                                  |
//+------------------------------------------------------------------+
struct PointEmission
  {
   double            x;       // X-  time
   double            y;       // Y-  price
   datetime          t;       // t-  
   bool              real;    //    
  };
//+------------------------------------------------------------------+
//|  CodeColor                                              |
//+------------------------------------------------------------------+
struct CodeColor
  {
   long              Code;    //    
   color             Color;   //  
   int               Width;   //  
  };
//+------------------------------------------------------------------+
//|                                           |
//+------------------------------------------------------------------+
class CEmission
  {
private:
   int               sec;
   int               lim_Left;   //     
   int               lim_Right;  //     

public:
   PointEmission     CalcPoint(double   y1,  // Y- 1   [1] 
                               double   y0,  // Y- 1   [0] 
                               double   yy1, // Y- 2   [1]  
                               double   yy0, // Y- 2   [0] 
                               datetime t0   // t-   Time[0]
                               );
   bool              CreatePoint(string name,            //  
                                 PointEmission &point,   //  
                                 CodeColor &style);      //   
                     CEmission(int limitLeft,int limitRight);
                    ~CEmission();
  };
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
CEmission::CEmission(int limitLeft,int limitRight)
  {
   sec=PeriodSeconds();
   lim_Left=limitLeft;
   lim_Right=limitRight;
  }
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
CEmission::~CEmission()
  {
  }
//+------------------------------------------------------------------+
//|  CalcPoint  CEmission                                 |
//+------------------------------------------------------------------+
PointEmission CEmission::CalcPoint(double   y1, // Y- 1   [1] 
                                   double   y0, // Y- 1   [0] 
                                   double   yy1,// Y- 2   [1]  
                                   double   yy0,// Y- 2   [0] 
                                   datetime t0  // t-   Time[0]
                                   )
  {
   PointEmission point={NULL,NULL,NULL,false};
   double y0y1=y0-y1;
   double y1yy1=y1-yy1;
   double yy0yy1=yy0-yy1;
   double del0=yy0yy1-y0y1;
   if(MathAbs(del0)>0)
     {
      point.x=y1yy1/del0;
      if(point.x<lim_Left || point.x>lim_Right) return(point);
      point.y=y1+y0y1*y1yy1/del0;
      if(point.y<0) return(point);
      point.t=t0+(int)(point.x*sec);
      point.real=true;
      return(point);
     }
   return(point);
  }
//+------------------------------------------------------------------+
//|  CreatePoint  CEmission                               |
//+------------------------------------------------------------------+
bool CEmission::CreatePoint(string name,           //  
                            PointEmission &point,  //  
                            CodeColor &style)      //   
  {
   if(ObjectCreate(0,name,OBJ_TEXT,0,0,0))
     {
      ObjectSetString(0,name,OBJPROP_FONT,"Wingdings");
      ObjectSetInteger(0,name,OBJPROP_ANCHOR,ANCHOR_CENTER);
      ObjectSetInteger(0,name,OBJPROP_FONTSIZE,style.Width);
      ObjectSetString(0,name,OBJPROP_TEXT,CharToString((uchar)style.Code));
      ObjectSetDouble(0,name,OBJPROP_PRICE,point.y);
      ObjectSetInteger(0,name,OBJPROP_TIME,point.t);
      ObjectSetInteger(0,name,OBJPROP_COLOR,style.Color);
      return(true);
     }
   return(false);
  }
//+------------------------------------------------------------------+
